@@ -17,6 +17,10 @@
 # shared main chain/side chain atoms
 sele_ms_shared = '(n. CA|n. N&r. PRO)'
 
+# text colors for delete and remove items
+del_col = r'\933'
+rem_col = r'\933'
+
 class menucontext(object):
     '''
     Singleton context manager class to store expensive metadata
@@ -56,7 +60,6 @@ def camera_store_with_scene(self_cmd,frame):
 
 
 def store_with_state(self_cmd,obj='',frame=0):
-    list = self_cmd.get_scene_list()[0:40] # keep this practical
     n_state = self_cmd.count_states()
     result = [[ 2, 'State:', ''],
               [ 1, 'current','cmd.mview("store",object="'+obj+'",state=-1,first=%s)'%(frame)],
@@ -446,6 +449,7 @@ def spectrum(self_cmd, sele):
     return r
 
 def by_chain(self_cmd, sele):
+    by_segi = r'\900b\950y \090s\099e\059g\705i\888 '
     return [
         [ 2, 'By Chain:'     ,''                               ],
               [ 1, '\\900b\\950y \\090c\\099h\\059a\\009i\\705n\\888(elem C)',
@@ -457,6 +461,9 @@ def by_chain(self_cmd, sele):
                       [ 0, ''                                , ''                 ],
               [ 1, '\\900c\\950h\\990a\\090i\\099n\\059b\\009o\\705w\\888s',
                  'util.chainbow("('+sele+')",_self=cmd)'],                                 
+              [ 0, '', '' ],
+              [ 1, by_segi + '(elem C)', 'cmd.spectrum("segi","rainbow","('+sele+') & elem C")'],
+              [ 1, by_segi, 'cmd.spectrum("segi","rainbow","' + sele + '")' ],
         ]
 
 rep_setting_lists = [
@@ -490,11 +497,9 @@ rep_setting_lists = [
         ('', 'cartoon_ring_color'),
         ('', 'ellipsoid_color'),
         ('', 'label_outline_color'),
-        ('', 'mesh_negative_color'),
         ('', 'ray_interior_color'),
         ('', 'ray_trace_color'),
         ('', 'stick_ball_color'),
-        ('', 'surface_negative_color'),
     ],
 ]
 
@@ -618,7 +623,7 @@ def all_colors_generic(self_cmd, expr):
     return r
 
 def all_colors(self_cmd, sele):
-    expr = 'util.color_deep("{0}", ' + repr(sele) + ')'
+    expr = 'util.color_deep("{0}", ' + repr(sele) + ', 0)'
     with menucontext(self_cmd, sele):
         return all_colors_generic(self_cmd, expr)
  
@@ -675,6 +680,21 @@ def measurement_color(self_cmd, sele):
     r += all_colors(self_cmd, sele)
     return r
 
+def mesh_color(self_cmd, name, rep='mesh'):
+    expr = ('cmd.set("%s_negative_visible",1,"%s",quiet=0);'
+            'cmd.set("%s_negative_color","{0}","%s",quiet=0)' % (rep, name, rep, name))
+    with menucontext(self_cmd, name):
+        negative = all_colors_generic(self_cmd, expr)
+        return [
+            [ 2, 'Color:', '' ],
+            [ 1, 'negative'  , [
+                [ 2, 'Negative Color:', '' ],
+                [ 1, 'off', 'cmd.set("%s_negative_visible",0,"%s",quiet=0);' % (rep, name) ],
+                [ 0, '', '' ],
+            ] + negative ],
+            [ 0, '', '' ],
+        ] + all_colors(self_cmd, name)
+
 def general_color(self_cmd, sele):
     return [[ 2, 'Color:'     ,''                        ]] + all_colors(self_cmd, sele)
 
@@ -694,6 +714,8 @@ def preset_ligand_sites(self_cmd, sele):
 
 def presets(self_cmd, sele):
     return [[ 2, 'Preset:'       ,''                        ],     
+              [ 1, 'classified', 'preset.classified("'+sele+'",_self=cmd)' ],
+              [ 0, '', '' ],
               [ 1, 'simple'   ,'preset.simple("'+sele+'",_self=cmd)'          ],
               [ 1, 'simple (no solvent)'   ,'preset.simple_no_solv("'+sele+'",_self=cmd)'          ],           
               [ 1, 'ball and stick' , 'preset.ball_and_stick("'+sele+'",_self=cmd)' ],
@@ -706,6 +728,8 @@ def presets(self_cmd, sele):
               [ 1, 'publication '   , 'preset.publication("'+sele+'",_self=cmd)'          ],
               [ 1, 'publication (with solvent)'   , 'preset.pub_solv("'+sele+'",_self=cmd)'          ],
               [ 0, ''               ,''                             ],                      
+              [ 1, 'protein interface', 'preset.interface("'+sele+'",_self=cmd)' ],
+              [ 0, '', '' ],
               [ 1, 'default'   ,'preset.default("'+sele+'",_self=cmd)'          ],           
               ]
 
@@ -724,6 +748,8 @@ def state(self_cmd, sele):
               [ 1, 'thaw'  ,
                   'cmd.unset("all_states","'+sele+'");'
                   'cmd.unset("state","'+sele+'")'        ],
+              [ 0, '', '' ],
+              [ 1, 'split'   ,'cmd.split_states("'+sele+'")' ],
               ]
     
 def movement(self_cmd, sele):
@@ -1072,7 +1098,7 @@ def modify_sele(self_cmd, sele):
               
 def sele_action(self_cmd, sele):
     return [[ 2, 'Action:'       ,''                        ],     
-              [ 1, 'delete selection', 'cmd.delete("'+sele+'")'          ],
+              [ 1, del_col + 'delete selection', 'cmd.delete("'+sele+'")'          ],
               [ 1, 'rename selection', 'cmd.wizard("renaming","'+sele+'")'          ],
               [ 0, ''               ,''                             ],
               [ 1, 'zoom'           ,'cmd.zoom("'+sele+'",animate=-1)'            ],
@@ -1088,7 +1114,7 @@ def sele_action(self_cmd, sele):
               [ 1, 'find', find(self_cmd, sele) ],
               [ 1, 'align', sele_align(self_cmd, sele) ],
               [ 0, ''               ,''                             ],
-              [ 1, 'remove atoms'   ,'cmd.remove("'+sele+'");cmd.delete("'+sele+'")'          ],
+              [ 1, rem_col + 'remove atoms'   ,'cmd.remove("'+sele+'");cmd.delete("'+sele+'")'          ],
               [ 1, 'hydrogens' , hydrogens(self_cmd, sele) ],
               [ 0, ''          ,''                                              ],
               [ 1, 'duplicate'      ,'cmd.select(None,"'+sele+'")'          ], # broken...
@@ -1103,13 +1129,13 @@ def sele_action(self_cmd, sele):
 
 def sele_action2(self_cmd, sele):
     return [[ 2, 'Action:'       ,''                        ],     
-              [ 1, 'delete selection', 'cmd.delete("'+sele+'")'          ],
+              [ 1, del_col + 'delete selection', 'cmd.delete("'+sele+'")'          ],
               [ 1, 'rename selection', 'cmd.wizard("renaming","'+sele+'")'          ],
               [ 0, ''               ,''                             ],
               [ 1, 'preset'         ,presets(self_cmd, sele)         ],
               [ 1, 'find', find(self_cmd, sele) ],
               [ 0, ''               ,''                             ],
-              [ 1, 'remove atoms'   ,'cmd.remove("'+sele+'");cmd.delete("'+sele+'")'          ],
+              [ 1, rem_col + 'remove atoms'   ,'cmd.remove("'+sele+'");cmd.delete("'+sele+'")'          ],
               [ 0, ''               ,''                             ],
               [ 1, 'around'         , around(self_cmd, sele)         ],           
               [ 1, 'expand'         , expand(self_cmd, sele)         ],
@@ -1145,10 +1171,10 @@ def group_action(self_cmd, sele):
             [ 1, 'assign sec. struc.'  ,'cmd.dss("'+sele+'")'        ],
             [ 0, ''             , ''                       ],
             [ 1, 'rename group', 'cmd.wizard("renaming","'+sele+'")'          ],
-            [ 1, 'delete group'       , 'cmd.delete("'+sele+'")'    ],
+            [ 1, del_col + 'delete group', 'cmd.delete("'+sele+'")'    ],
             [ 0, ''          ,''                                              ],
             [ 1, 'hydrogens' , hydrogens(self_cmd, sele)    ],           
-            [ 1, 'remove waters'  ,'cmd.remove("(solvent and ('+sele+'))")'     ],
+            [ 1, rem_col + 'remove waters', 'cmd.remove("(solvent and ('+sele+'))")'     ],
             [ 0, ''          ,''                                              ],
             [ 1, 'state'          , state(self_cmd, sele)         ],                      
             [ 1, 'masking'        , masking(self_cmd, sele)         ],
@@ -1179,10 +1205,10 @@ def mol_action(self_cmd, sele):
             [ 0, ''             , ''                       ],
             [ 1, 'rename object', 'cmd.wizard("renaming","'+sele+'")'          ],
             [ 1, 'duplicate object'    ,'cmd.create(None,"'+sele+'")'     ],           
-            [ 1, 'delete object'       , 'cmd.delete("'+sele+'")'    ],
+            [ 1, del_col + 'delete object', 'cmd.delete("'+sele+'")'    ],
             [ 0, ''          ,''                                              ],
             [ 1, 'hydrogens' , hydrogens(self_cmd, sele)    ],           
-            [ 1, 'remove waters'  ,'cmd.remove("(solvent and ('+sele+'))")'     ],
+            [ 1, rem_col + 'remove waters', 'cmd.remove("(solvent and ('+sele+'))")'     ],
             [ 0, ''          ,''                                              ],
               [ 1, 'state'          , state(self_cmd, sele)         ],                      
               [ 1, 'masking'        , masking(self_cmd, sele)         ],
@@ -1208,7 +1234,7 @@ def slice_action(self_cmd, sele):
               [ 0, ''             , ''                       ],
               [ 1, 'rename'       , 'cmd.wizard("renaming","'+sele+'")'          ],           
               [ 0, ''             , ''                       ],
-              [ 1, 'delete'       , 'cmd.delete("'+sele+'")'    ],
+              [ 1, del_col + 'delete', 'cmd.delete("'+sele+'")'    ],
               ]
 
 def simple_action(self_cmd, sele):
@@ -1223,9 +1249,15 @@ def simple_action(self_cmd, sele):
             [ 0, ''             , ''                       ],
             [ 1, 'rename'       , 'cmd.wizard("renaming","'+sele+'")'          ],           
             [ 0, ''             , ''                       ],
-            [ 1, 'delete'       , 'cmd.delete("'+sele+'")'    ],
+            [ 1, del_col + 'delete', 'cmd.delete("'+sele+'")'    ],
               ]
 
+def iso_with_negative(mapname, suffix, rep, level=1, color='blue'):
+    name = mapname + suffix
+    return ('cmd.iso%s("%s","%s", %s);\n'
+            'cmd.set("%s_negative_visible",1,"%s",quiet=0);\n'
+            'cmd.color("%s","%s")' % (rep, name, mapname, level, rep, name, color, name))
+
 def map_mesh(self_cmd, sele):
     return [[ 2, 'Mesh:',  '' ],
             [ 1, '@ level 1.0'         , 'cmd.isomesh("'+sele+'_mesh","'+sele+'",1.0)'      ],
@@ -1233,6 +1265,9 @@ def map_mesh(self_cmd, sele):
             [ 1, '@ level 2.0'         , 'cmd.isomesh("'+sele+'_mesh","'+sele+'",2.0)'      ],
             [ 1, '@ level 3.0'         , 'cmd.isomesh("'+sele+'_mesh","'+sele+'",3.0)'      ],            
             [ 0, ''             , ''                       ],            
+            [ 1, '@ level +/-1.0'      , iso_with_negative(sele, '_mesh', 'mesh')],
+            [ 1, '@ level +/-3.0'      , iso_with_negative(sele, '_mesh', 'mesh', 3, 'green')],
+            [ 0, ''             , ''                       ],
             [ 1, '@ level 0.0'         , 'cmd.isomesh("'+sele+'_mesh","'+sele+'",0.0)'      ],
             [ 1, '@ level -1.0'         , 'cmd.isomesh("'+sele+'_mesh","'+sele+'",-1.0)'      ],
             [ 1, '@ level -2.0'         , 'cmd.isomesh("'+sele+'_mesh","'+sele+'",-2.0)'      ],
@@ -1256,6 +1291,9 @@ def map_surface(self_cmd, sele):
             [ 1, '@ level 2.0'         , 'cmd.isosurface("'+sele+'_surf","'+sele+'",2.0)'      ],
             [ 1, '@ level 3.0'         , 'cmd.isosurface("'+sele+'_surf","'+sele+'",3.0)'      ],            
             [ 0, ''             , ''                       ],
+            [ 1, '@ level +/-1.0'      , iso_with_negative(sele, '_surf', 'surface')],
+            [ 1, '@ level +/-3.0'      , iso_with_negative(sele, '_surf', 'surface', 3, 'green')],
+            [ 0, ''             , ''                       ],
             [ 1, '@ level 0.0'         , 'cmd.isosurface("'+sele+'_surf","'+sele+'",0.0)'      ],            
             [ 1, '@ level -1.0'         , 'cmd.isosurface("'+sele+'_surf","'+sele+'",-1.0)'      ],
             [ 1, '@ level -2.0'         , 'cmd.isosurface("'+sele+'_surf","'+sele+'",-2.0)'      ],
@@ -1297,7 +1335,7 @@ def map_action(self_cmd, sele):
             [ 0, ''             , '' ],
             [ 1, 'rename'       , 'cmd.wizard("renaming","'+sele+'")'          ],           
             [ 0, ''             , ''                       ],
-            [ 1, 'delete'       , 'cmd.delete("'+sele+'")'    ],
+            [ 1, del_col + 'delete', 'cmd.delete("'+sele+'")'    ],
             ]
 
 def level(self_cmd, sele):
@@ -1332,7 +1370,7 @@ def surface_action(self_cmd, sele):
             [ 0, ''             , ''                       ],
             [ 1, 'rename'       , 'cmd.wizard("renaming","'+sele+'")'          ],           
             [ 0, ''             , ''                       ],
-            [ 1, 'delete'       , 'cmd.delete("'+sele+'")'    ],
+            [ 1, del_col + 'delete', 'cmd.delete("'+sele+'")'    ],
             ]
 
 def mesh_action(self_cmd, sele):
@@ -1348,12 +1386,12 @@ def mesh_action(self_cmd, sele):
             [ 0, ''             , ''                       ],
             [ 1, 'rename'       , 'cmd.wizard("renaming","'+sele+'")'          ],           
             [ 0, ''             , ''                       ],
-            [ 1, 'delete'       , 'cmd.delete("'+sele+'")'    ],
+            [ 1, del_col + 'delete', 'cmd.delete("'+sele+'")'    ],
             ]
 
 def ramp_action(self_cmd, sele):
     return [[ 2, 'Action:'     , ''                       ],
-              [ 1, 'delete'       , 'cmd.delete("'+sele+'")'    ],
+              [ 1, del_col + 'delete', 'cmd.delete("'+sele+'")'    ],
               [ 0, '', '' ],
               [ 1, 'levels', [
                   [ 1, 'Range +/- %.1f' % (L),
@@ -1370,7 +1408,7 @@ def ramp_color(self_cmd, sele):
                     for name in [
                         '[red, white, blue]',
                         ] + list(ramp_spectrum_dict)
-              ]
+            ]
 
 def test1(self_cmd, sele):
         return [[ 2, 'Test1:'     , ''                      ],     
@@ -1398,11 +1436,11 @@ def all_action(self_cmd, sele):
               [ 1, 'hydrogens' ,hydrogens(self_cmd, sele)     ],
 #              [ 1, 'add hydrogens' ,'cmd.h_add("'+sele+'")'     ],           
 #              [ 1, 'remove hydrogens'  ,'cmd.remove("(hydro and ('+sele+'))")'     ],
-              [ 1, 'remove waters'  ,'cmd.remove("(solvent and ('+sele+'))")'     ],                      
+              [ 1, rem_col + 'remove waters', 'cmd.remove("(solvent and ('+sele+'))")'     ],
               [ 0, ''             , ''                      ],
-              [ 1, 'delete selections'  , 'map(cmd.delete,cmd.get_names("selections"))'     ],           
+              [ 1, del_col + 'delete selections', 'map(cmd.delete,cmd.get_names("selections"))'     ],
               [ 0, ''          ,''                                              ],
-              [ 1, 'delete everything'  , 'cmd.delete("all")'     ],           
+              [ 1, del_col + 'delete everything', 'cmd.delete("all")'     ],
               [ 0, ''          ,''                                              ],
               [ 1, 'masking'      , masking(self_cmd, sele)         ],                      
               [ 1, 'movement'       , movement(self_cmd, sele)         ],
@@ -1413,7 +1451,7 @@ def label_props(self_cmd, sele):
     return [[ 2, 'Other Properties:'       ,''                        ],     
                              
               [ 1, 'formal charge' , 
-  'cmd.label("'+sele+'","\'%d\'%formal_charge")'                      ],
+  'cmd.label("'+sele+'","(\'%+d\'%formal_charge) if formal_charge else \'\'")' ],
               [ 0, ''               , ''                                  ],
               [ 1, 'partial charge (0.00)' ,            
   'cmd.label("'+sele+'","\'%.2f\'%partial_charge")'                      ],
@@ -1491,18 +1529,21 @@ def all_option(self_cmd, sele):
         ]
     
 def enable_disable(self_cmd, enable):
+    names_enabled = self_cmd.get_names('objects', enabled_only=1)
     if enable:
         result = [[ 2, 'Enable', '' ]]
-        cmmd = 'cmd.enable("'
+        cmmd = 'enable '
+        names = [ob for ob in self_cmd.get_names('objects')
+                 if ob not in names_enabled]
     else:
         result = [[ 2, 'Disable', '']]
-        cmmd = 'cmd.disable("'
-    result = result + list(map(lambda ob,cm=cmmd:[1,ob,cm+ob+'")'],['all']+self_cmd.get_names('objects')))
+        cmmd = 'disable '
+        names = names_enabled
+    names = ['all'] + names
+    result += [[1, ob, cmmd + ob] for ob in names]
+    result.insert(2, [0, '', ''])
     if not enable:
-        result.insert(2,[1, 'selections', "util.hide_sele(_self=cmd)"])
-    else:
-        result2 = [[ 2, 'Selections', '']]
-        
+        result.insert(2, [1, 'selections', 'deselect'])
     return result
 
 def scene_buttons(self_cmd):
@@ -1577,9 +1618,9 @@ def main_menu(self_cmd,pos):
         [ 0, ''             , ''                      ],
         [ 1, 'ray'           ,'cmd.ray()' ],
         [ 0, ''             , ''                      ],
-        [ 1, 'delete all'           ,'cmd.delete("all")' ],
-        [ 1, 'reinitialize'           ,'cmd.reinitialize()' ],
-        [ 1, 'quit'           ,'cmd.quit()' ],
+        [ 1, del_col + 'delete all', 'cmd.delete("all")' ],
+        [ 1, del_col + 'reinitialize', 'cmd.reinitialize()' ],
+        [ 1, del_col + 'quit', 'cmd.quit()' ],
         ]
 
 def pick_sele_sub(self_cmd, sele):
@@ -1587,10 +1628,10 @@ def pick_sele_sub(self_cmd, sele):
         [ 2, 'Actions'  , '' ],      
         [ 1, 'rename', 'cmd.wizard("renaming","'+sele+'")'          ],
         [ 1, 'clear'    , 'cmd.select("'+sele+'","none")' ],
-        [ 1, 'delete selection', 'cmd.delete("'+sele+'")' ],
+        [ 1, del_col + 'delete selection', 'cmd.delete("'+sele+'")' ],
         [ 1, 'copy to object','cmd.create(None,"'+sele+'",zoom=0)'            ],
         [ 1, 'extract object' ,'cmd.extract(None,"'+sele+'",zoom=0)' ],
-        [ 1, 'remove atoms'  , 'cmd.remove("'+sele+'")' ],     
+        [ 1, rem_col + 'remove atoms', 'cmd.remove("'+sele+'")' ],
         ]
     return result
 
@@ -1615,7 +1656,7 @@ def pick_sele(self_cmd, sele, title):
         [ 1, 'drag'             ,'cmd.drag("'+sele+'")'            ],
         [ 1, 'clean'             ,'cmd.clean("'+sele+'")'            ],        
         [ 0, ''               ,''                             ],        
-        [ 1, 'remove'             ,'cmd.remove("'+sele+'")'            ],
+        [ 1, rem_col + 'remove', 'cmd.remove("'+sele+'")'            ],
         ]
     return result
     
@@ -1654,13 +1695,13 @@ def pick_option(self_cmd, sele, title, object=0):
   
     if object:
         result.extend([
-            [ 1, 'delete'        ,'cmd.delete("'+sele+'")'            ],
+            [ 1, del_col + 'delete', 'cmd.delete("'+sele+'")'            ],
             [ 0, ''             , ''                      ],         
             [ 1, 'disable'        ,'cmd.disable("'+sele+'")'            ],
             ])
     else:
         result.extend([
-            [ 1, 'remove atoms' , 'cmd.remove("'+sele+'")' ],     
+            [ 1, rem_col + 'remove atoms', 'cmd.remove("'+sele+'")' ],
             [ 0, ''             , ''                      ],      
             [ 1, 'copy to object','cmd.create(None,"'+sele+'",zoom=0)'            ],
             [ 1, 'extract object' ,'cmd.extract(None,"'+sele+'",zoom=0)' ],
@@ -1689,22 +1730,6 @@ def pick_menu(self_cmd, title, sele2):
             [ 1, 'fragment', pick_option(self_cmd, "(byfrag ("+sele2+"))", "Fragment") ],
             [ 1, 'fragment+joint(s)', pick_option(self_cmd, "((byfrag ("+sele2+")) extend 1)", "Fragment") ],
             ]
-        
-def seq_menu(sele2,sele3): # obsolete/unused?
-    
-    return [[ 2, 'Sequence'    , '' ],
-              [ 1, 'selection', pick_option(self_cmd, sele3, '('+sele3+')') ],
-              [ 0, ''             , ''                      ],
-              [ 1, 'residue' , pick_option(self_cmd, "(byres ("+sele2+"))", "Residue",) ],
-              [ 1, 'chain'   , pick_option(self_cmd, "(bychain ("+sele2+"))", "Chain",) ],
-              [ 1, 'segment' , pick_option(self_cmd, "(byseg ("+sele2+"))", "Segment",) ],
-              [ 1, 'object'  , pick_option(self_cmd, "(byobject ("+sele2+"))", "Object",1) ],
-              [ 0, ''             , ''                      ],
-              [ 1, 'molecule', pick_option(self_cmd, "(bymol ("+sele2+"))", "Molecule") ],
-              [ 0, ''             , ''                      ],
-              [ 1, 'C-alpha'    , pick_option(self_cmd, "(bycalpha ("+sele2+"))", "C-alpha") ],
-              ]
-        
 
 def seq_option(self_cmd, sele, title, object=0):
     c=len(title)-1
@@ -1735,7 +1760,7 @@ def seq_option(self_cmd, sele, title, object=0):
             [ 0, ''             , ''                      ],         
             [ 1, 'disable'        ,'cmd.disable("'+sele+'")'            ],
             [ 0, ''             , ''                      ],
-            [ 1, 'delete'        ,'cmd.delete("'+sele+'")'            ]         
+            [ 1, del_col + 'delete', 'cmd.delete("'+sele+'")'            ]
             ])
     else:
         result.extend([
@@ -1743,7 +1768,7 @@ def seq_option(self_cmd, sele, title, object=0):
             [ 1, 'create object','cmd.create(None,"'+sele+'",zoom=0)'            ],
             [ 1, 'extract object' ,'cmd.extract(None,"'+sele+'",zoom=0)' ],
             [ 0, ''             , ''                      ],
-            [ 1, 'remove atoms' , 'cmd.remove("'+sele+'")' ],     
+            [ 1, rem_col + 'remove atoms', 'cmd.remove("'+sele+'")' ],
             ])
     return result
     
@@ -1754,6 +1779,6 @@ def scene_menu(self_cmd, name):
             [ 0, ''             , ''                      ],
             [ 1, 'update', 'cmd.scene("'+safe_name+'","update")'],
             [ 0, ''             , ''                      ],
-            [ 1, 'delete', 'cmd.scene("'+safe_name+'","delete")'],
+            [ 1, del_col + 'delete', 'cmd.scene("'+safe_name+'","delete")'],
             ]
    
